﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace OPCClient
{
    /// <summary>
    /// Main class from OPCClient assembly. This class is used for configuring OPC tags.
    /// </summary>
    public partial class OPCConfig : Form
    {
        //creating an instance of the OPCTagConfig class so we could pass a values to OPCTagConfig instance properties
        public OPCTagConfig opcTagConfig = new OPCTagConfig();

        /// <summary>
        /// Default constructor of the OPCConfig class. Creates new OPCConfig form.
        /// </summary>
        public OPCConfig()
        {
            InitializeComponent();
        }


        #region acquiring and configuring values from OPCSystems.NET repository (local/network nodes)

        private void OPCConfig_Load(object sender, EventArgs e)
        {
            getHosts();
        }

        private void opcTreeView_AfterSelect(object sender, TreeViewEventArgs e)
        {
            opcListBox.Items.Clear();

            if (e.Node.Level == 0)
            {
                opcTagConfig.Host = e.Node.Text;
                opcTagConfig.Group = "";
                e.Node.Nodes.Clear();
                getGroups("", e.Node);
                getTags();
            }

            if (e.Node.Level > 0)
            {
                opcTagConfig.Group = e.Node.Text;
                getTags();
            }
        }

        private void opcListBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            opcTagConfig.Tag = (String)opcListBox.Items[opcListBox.SelectedIndex];
            tagNameLabel.Text = opcTagConfig.Tag;
            okButton.Enabled = true;
            timer1.Start();
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            try
            {
                getTagValue();
                tagValueLabel.Text = opcTagConfig.TempValue.ToString();
                RemoveErrorDescriptionText();
            }
            catch (Exception ex)
            {
                problemLabel.Text = "Error in displaying opc tag value";
                ex = new Exception("Choose a tag that represents a number value");
                causeOfProblemLabel.Text = ex.Message;
            }
        }

        #endregion


        #region methods for browsing hosts, groups and tags and getting tag value

        private void getHosts()
        {
            opcTreeView.Nodes.Clear();
            opcListBox.Items.Clear();

            foreach (string host in opcSystemsComponent1.GetNetworkNodes())
            {
                opcTreeView.Nodes.Add(host);
            }
        }

        private void getGroups(string parentGroup, TreeNode parentNode)
        {
            foreach (string group in opcSystemsComponent1.GetGroupNames(parentGroup, opcTagConfig.Host))
            {
                TreeNode currentNode = parentNode.Nodes.Add(group);
                getGroups(group, currentNode);
            }
        }

        private void getTags()
        {
            foreach (string tag in opcSystemsComponent1.GetTagNames(opcTagConfig.Group, opcTagConfig.Host))
            {
                opcListBox.Items.Add(tag);
            }
        }

        private void getTagValue()
        {
            opcTagConfig.TempValue = Convert.ToDouble
            (opcSystemsComponent1.GetTag_Parameter_Value("Value", "Value", opcTagConfig.Tag, opcTagConfig.Group, opcTagConfig.Host));
        }

        #endregion


        private void RemoveErrorDescriptionText()
        {
            problemLabel.Text = "";
            causeOfProblemLabel.Text = "";
        }

        private void okButton_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.OK;
        }

        private void cancelButton_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
        }
    }
}
