﻿using System;
using System.Collections.Generic;
using System.Text;

namespace OPCClient
{
    /// <summary>
    /// Class that represents OPC configuration parameters. This class serves like a side class of the OPCConfig class.
    /// </summary>
    public class OPCTagConfig
    {
        //OPCTagConfig class atributes.
        //You cannot access them outside this class. 
        //Instead, use their corresponding property methods.
        private string host = null;
        private string group = null;
        private string tag = null;
        private double tempValue;

        /// <summary>
        /// Default constructor of the OPCTagConfig class
        /// </summary>
        public OPCTagConfig() { }

        /// <summary>
        /// Computer name / Root node
        /// </summary>
        /// <remarks>
        /// Use the <b>Host</b> property to root node for OPC Tag source. Host can be local computer or remote computer on the network. 
        /// </remarks>
        public string Host
        {
            get { return host; }
            set { host = value; }
        }

        /// <summary>
        /// OPC group on choosen host node
        /// </summary>
        /// <remarks>
        /// Use the <b>Group</b> property to specify OPC Group that contains OPC Tags. 
        /// </remarks>
        public string Group
        {
            get { return group; }
            set { group = value; }
        }

        /// <summary>
        /// OPC tag name
        /// </summary>
        /// <remarks>
        /// Use the <b>Tag</b> property to specify the name of the OPC Tag.
        /// </remarks>
        public string Tag
        {
            get { return tag; }
            set { tag = value; }
        }

        /// <summary>
        /// Value of the OPC tag
        /// </summary>
        /// <remarks>
        /// Use the <b>TempValue</b> property to temporary store a value from choosen OPC Tag.
        /// </remarks>
        public double TempValue
        {
            get { return tempValue; }
            set { tempValue = value; }
        }
    }
}
