﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace Pump
{
    /// <summary>
    /// Pump control configuration class
    /// </summary>
    public partial class PumpControlConfig : Form
    {
        //Local atribute that is used for passing a value of that atribute to corresponding atribute on pump control.
        //You cannot access that atribute outside this class. 
        //Instead, use his corresponding property method.
        private double tempLimitValue;

        /// <summary>
        /// Default constructor of the PumpControlConfig class. Creates new PumpControlConfigConfig form.
        /// </summary>
        public PumpControlConfig()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Temporary limit property that stores choosen limit value for pump control
        /// </summary>
        /// <remarks>
        /// This property is used only for passing a value to pump controls.
        /// </remarks>
        public double TempLimitValue
        {
            get { return tempLimitValue; }
            protected set { tempLimitValue = value; }
        }

        /// <summary>
        /// Refresh time of the pump control
        /// </summary>
        /// <remarks>
        /// This property is used for setting a refresh time of the pump control.
        /// </remarks>
        public int RefreshTime
        {
            get { return refreshTimer.Interval; }
            protected set { refreshTimer.Interval = value; }
        }

        #region configuration of the limit pump value

        private void setLimitValueButton_Click(object sender, EventArgs e)
        {
            try
            {
                this.TempLimitValue = Convert.ToDouble(setLimitValueTextBox.Text);
                okButton.Enabled = true;
                RemoveErrorDescriptionText();
            }
            catch (FormatException ex)
            {
                problemLabel.Text = "Pump Limit value is not configured";
                ex = new FormatException("Pump Limit value is not entered in a correct format");
                causeOfProblemLabel.Text = ex.Message;
            }
        }

        #endregion


        #region refresh time of the control (miliseconds) - default value is 100

        private void refreshTimeConfigurationButton_Click(object sender, EventArgs e)
        {
            try
            {
                this.RefreshTime = int.Parse(refreshTimeTextBox.Text);
            }
            catch (FormatException formatError3)
            {
                problemLabel.Text = "Indicator of permitted value is not configured";
                formatError3 = new FormatException("Refresh time value is not entered in a correct format");
                causeOfProblemLabel.Text = formatError3.Message;
            }
        }

        #endregion

        private void RemoveErrorDescriptionText()
        {
            problemLabel.Text = "";
            causeOfProblemLabel.Text = "";
        }

        private void okButton_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.OK;
        }

        private void cancelButton_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
        }
    }
}
