﻿using System;
using System.Collections.Generic;
using System.Drawing.Design;
using System.ComponentModel.Design;
using System.Text;
using System.ComponentModel;
using System.Windows.Forms.Design;
using System.Windows.Forms;
using OPCClient;

namespace Pump
{
    //Class that derives from UITypeEditor class. 
    //This class provides a possibility for connecting pump controls with OPCClient in desing time mode.
    //You can open OPCConfig form in desing time mode using Properties window and choose desired OPC Tag.
    /// <summary>
    /// Pump control OPC Editor class
    /// </summary>
    public class PumpControlOPCEditor : UITypeEditor
    {
        /// <summary>
        /// Overrided method for defining a style of editor
        /// </summary>
        /// <remarks>   
        /// This method returns type of editor that we want to use in desing-time mode. In this case, it is modal dialog.
        /// </remarks>
        public override UITypeEditorEditStyle GetEditStyle(System.ComponentModel.ITypeDescriptorContext context)
        {
            return UITypeEditorEditStyle.Modal;
        }

        /// <summary>
        /// Overrided method that defines a value that we want to edit in desing-time mode
        /// </summary>
        /// <remarks>   
        /// This method is used for defining a form that we want to open with this modal type editor. In this case, we will open OPCConfig class form.
        /// After we configure opcTagConfig object in OPCConfig form, using this method, we will return opcTagConfig object reference to OpcTagConfig property of the pump control.
        /// </remarks>
        public override object EditValue(ITypeDescriptorContext context, IServiceProvider provider, object value)
        {
            if ((context != null) && (provider != null))
            {
                IWindowsFormsEditorService editorService =
                  (IWindowsFormsEditorService)
                provider.GetService(typeof(IWindowsFormsEditorService));

                if (editorService != null)
                {
                    OPCConfig opcConfig = new OPCConfig();

                    opcConfig.opcTagConfig = (OPCTagConfig)value;

                    if (editorService.ShowDialog(opcConfig) == DialogResult.OK)
                    {
                        return opcConfig.opcTagConfig;
                    }
                }
            }
            return base.EditValue(context, provider, value);
        }
    }
}
